@@ -4,8 +4,8 @@ __author__ = ('Aitor Blanco Miguez (aitor.blancomiguez@unitn.it), '
               'Francesco Asnicar (f.asnicar@unitn.it), '
               'Moreno Zolfo (moreno.zolfo@unitn.it), '
               'Francesco Beghini (francesco.beghini@unitn.it)')
-__version__ = '3.0'
-__date__ = '21 Feb 2020'
+__version__ = '3.0.8'
+__date__ = '7 May 2021'
 
 import sys
 try:
@@ -139,4 +139,4 @@ def main():
          init_new_line=True)
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
